# frozen_string_literal: true

require 'spec_helper'

describe 'Query.project(fullPath).vulnerabilitySeveritiesCount' do
  let_it_be(:project) { create(:project) }
  let_it_be(:user) { create(:user) }
  let_it_be(:vulnerability) { create(:vulnerability, project: project, severity: :high) }

  let_it_be(:query) do
    %(
      query {
        project(fullPath:"#{project.full_path}") {
          vulnerabilitySeveritiesCount {
            high
          }
        }
      }
    )
  end

  before do
    project.add_developer(user)
  end

  subject { GitlabSchema.execute(query, context: { current_user: user }).as_json }

  context 'when first_class_vulnerabilities is disabled' do
    before do
      stub_feature_flags(first_class_vulnerabilities: false)
    end

    it 'is null' do
      vulnerabilities = subject.dig('data', 'project', 'vulnerabilitySeveritiesCount')

      expect(vulnerabilities).to be_nil
    end
  end

  context 'when first_class_vulnerabilities is enabled' do
    before do
      stub_feature_flags(first_class_vulnerabilities: true)
      stub_licensed_features(security_dashboard: true)
    end

    it "returns counts for each severity of the project's vulnerabilities" do
      high_count = subject.dig('data', 'project', 'vulnerabilitySeveritiesCount', 'high')

      expect(high_count).to be(1)
    end
  end
end
